@@ -1,14 +1,17 @@
 #!/usr/bin/perl
+
 package TestExecutor;
-use Mesos::Messages;
 use Moo;
+use strict;
+use warnings;
 extends 'Mesos::Executor';
+use Mesos::Messages;
 
 sub launchTask {
     my ($self, $driver, $task) = @_;
-    printf "Running task %s\n", $task->{task_id}{value};
+    printf "Running task %s\n", $task->task_id->value;
     my $update = Mesos::TaskStatus->new({
-        task_id => $task->{task_id},
+        task_id => $task->task_id,
         state   => Mesos::TaskState::TASK_RUNNING,
         data    => "data with a \0 byte",    
     });
@@ -16,7 +19,7 @@ sub launchTask {
 
     print "Sending status update...\n";
     $update = Mesos::TaskStatus->new({
-        task_id => $task->{task_id},
+        task_id => $task->task_id,
         state   => Mesos::TaskState::TASK_FINISHED,
         data    => "data with a \0 byte",    
     });
