@@ -1,7 +1,9 @@
 package Mesos::Executor;
-use Mesos::Messages;
 use Moo;
-use namespace::autoclean;
+use strict;
+use warnings;
+
+with 'Mesos::Role::Executor';
 
 sub registered {}
 sub reregistered {}
@@ -13,15 +15,15 @@ sub shutdown {}
 sub error {}
 
 
-=head1 NAME
+=head1 Name
 
 Mesos::Executor - base class for Mesos executors
 
-=head1 SYNOPSIS
+=head1 Synopsis
 
 Mesos::Executor methods are callbacks which will are invoked by Mesos::ExecutorDriver.
 
-=head1 METHODS
+=head1 Methods
 
 =over 4
 
