@@ -4,11 +4,11 @@ use Moo::Role;
 use strict;
 use warnings;
 
-use Mesos::Channel::Pipe;
+use Mesos::Channel;
 
 has channel => (
     is      => 'ro',
-    default => sub { Mesos::Channel::Pipe->new },
+    default => sub { Mesos::Channel->new },
 );
 
 has return => (
