@@ -29,7 +29,7 @@ sub BUILD {
     $self->channel($self->scheduler->channel);
 }
 
-with 'Mesos::Role::Dispatcher::AnyEvent';
+with 'Mesos::Role::Dispatcher';
 
 
 1;
